pub trait TypeUuidDynamic: Sealed {
// Required method
fn uuid(&self) -> Bytes;
}Expand description
Allows the TypeUuid constants to be retrieved via a trait object.
This trait is sealed and cannot be implemented outside of the type-uuid
codebase. It is implemented automatically for all types that implement
TypeUuid, which you should implement instead.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".